[![Tests](https://github.com/cjolowicz/cutty/workflows/Tests/badge.svg)](https://github.com/cjolowicz/cutty/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/cjolowicz/cutty/branch/master/graph/badge.svg)](https://codecov.io/gh/cjolowicz/cutty)
[![PyPI](https://img.shields.io/pypi/v/cutty.svg)](https://pypi.org/project/cutty/)
[![Python Version](https://img.shields.io/pypi/pyversions/cutty)](https://pypi.org/project/cutty)
[![Read the Docs](https://readthedocs.org/projects/cutty/badge/)](https://cutty.readthedocs.io/)
[![License](https://img.shields.io/pypi/l/cutty)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# cutty
